@@ -1,10 +1,10 @@
 from aries_cloudagent.messaging.base_handler import (
     BaseHandler,
     BaseResponder,
-    RequestContext
+    RequestContext,
 )
+from dexa_protocol.v1_0.messages.negotiation.offer_dda import OfferDDAMessage
 from dexa_sdk.managers.dexa_manager import DexaManager
-from ..messages.negotiation.offer_dda import OfferDDAMessage
 
 
 class OfferDDAMessageHandler(BaseHandler):
@@ -19,7 +19,4 @@ class OfferDDAMessageHandler(BaseHandler):
         mgr = DexaManager(context)
 
         # Process the message.
-        await mgr.process_offer_dda_message(
-            context.message,
-            context.message_receipt
-        )
+        await mgr.process_offer_dda_message(context.message, context.message_receipt)
